% This program solves for the effective index of the slab waveguide. It is based on 
% the paper by H Kogelnik and V Ramaswamy, August 1974, Vol 13, No 8, Applied Optics, 
% page 1857 Copyright Milan Masanovic, January 2001

% define the waveguide parameters
%         =================
%         ===== Nc ========
%         =================
%         /////////////////  |
%         ///// Nf ////////  | d
%         /////////////////  |
%         \\\\\\\\\\\\\\\\\
%         \\\\\ Ns \\\\\\\\
%         \\\\\\\\\\\\\\\\\
% define V,a,m as global variables
clear all;
global V a m
% ! WARNING - Ns ALWAYS has to be greater that Nc !
Nc = 3.17;
Nf = 3.4082;
Ns = 3.17;
% free space wavelength (microns)
lambda = 1.55;
% waveguide width (microns)
d = 0.3:0.01:0.4;
len = length(d)
N_eff_q = zeros(1,len);
for j=1:len
   % mode number 
   m = 0;
   % free space wave vector
   k = 2.*pi./lambda;
   % normalized waveguide thickness
   V = k.*d(j).*sqrt(Nf^2-Ns^2);
   % asymmetry measure
   a = (Ns^2-Nc^2)/(Nf^2-Ns^2);
   % calculate all the possible values for V vs b combination
   b = 0:0.01:0.99;
   V1 = 1./sqrt(1-b).*(m.*pi + atan(sqrt(b./(1-b)))+atan(sqrt((b+a)./(1-b))));
   % find a value of b close to V
   len = length(b);
   i = 1;
   while V1(i) < V
     i = i+1;
   end
   % calculate the actual b and N_eff
   answer = fzero('f',b(i));
   N_eff_q(j) = sqrt(Ns^2+answer.*(Nf^2-Ns^2));
end
Nc = 1;
Nf = 3.4082;
Ns = 3.17;
% free space wavelength (microns)
lambda = 1.55;
% waveguide width (microns)
d = 0.3:0.01:0.4;
len = length(d)
N_eff_inp = zeros(1,len);
for j=1:len
   % mode number 
   m = 0;
   % free space wave vector
   k = 2.*pi./lambda;
   % normalized waveguide thickness
   V = k.*d(j).*sqrt(Nf^2-Ns^2);
   % asymmetry measure
   a = (Ns^2-Nc^2)/(Nf^2-Ns^2);
   % calculate all the possible values for V vs b combination
   b = 0:0.01:0.99;
   V1 = 1./sqrt(1-b).*(m.*pi + atan(sqrt(b./(1-b)))+atan(sqrt((b+a)./(1-b))));
   % find a value of b close to V
   len = length(b);
   i = 1;
   while V1(i) < V
     i = i+1;
   end
   % calculate the actual b and N_eff
   answer = fzero('f',b(i));
   N_eff_inp(j) = sqrt(Ns^2+answer.*(Nf^2-Ns^2));
end
figure(1);
plot(d,N_eff_q,d,N_eff_inp);
title(strcat('Effective Index Data for 1.34Q InGaAsP, InP, and their 1D Effective Indices'));
xlabel('Waveguide Thicknes (nm)');
ylabel('Effective Index n');
legend('Effective Index - 1.34Q','Effective Index - InP');
grid on;