% This program solves for the effective index of the slab waveguide. It is based on 
% the paper by H Kogelnik and V Ramaswamy, August 1974, Vol 13, No 8, Applied Optics, 
% page 1857 Copyright Milan Masanovic, January 2001

% define the waveguide parameters
%         =================
%         ===== Nc ========
%         =================
%         /////////////////  |
%         ///// Nf ////////  | d
%         /////////////////  |
%         \\\\\\\\\\\\\\\\\
%         \\\\\ Ns \\\\\\\\
%         \\\\\\\\\\\\\\\\\
% define V,a,m as global variables
clear all;
global V a m
% ! WARNING - Ns ALWAYS has to be greater that Nc !
Nc = 3.2322;
Nf = 3.2920;
Ns = 3.2322;
% free space wavelength (microns)
lambda = 1.55;
% waveguide width (microns)
d = 1.2;
% mode number 
m = 0;
% free space wave vector
k = 2.*pi./lambda;
% normalized waveguide thickness
V = k.*d.*sqrt(Nf^2-Ns^2);
% asymmetry measure
a = (Ns^2-Nc^2)/(Nf^2-Ns^2);
% calculate all the possible values for V vs b combination
b = 0:0.01:0.99;
V1 = 1./sqrt(1-b).*(m.*pi + atan(sqrt(b./(1-b)))+atan(sqrt((b+a)./(1-b))));
% find a value of b close to V
len = length(b);
i = 1;
while V1(i) < V
   i = i+1;
end
% calculate the actual b and N_eff
answer = fzero('f',b(i))
N_eff = sqrt(Ns^2+answer.*(Nf^2-Ns^2))
% total number of the modes
n_modes = floor((V-atan(sqrt(a)))./pi)+1;
% Plot the graph and the solution, together with parameter values
figure(1);
plot(V1,b,'r',V,answer,'go');
title(strcat('Total number of supported modes =',num2str(n_modes)));
a_legend = strcat('a=',num2str(a),', ');
m_legend = strcat('m=',num2str(m));
legend(strcat(a_legend,m_legend),strcat('N_{eff}=',num2str(N_eff)),0);
xlabel('normalized waveguide width V');
ylabel('normalized guide index b');
text(15.5,0.25,strcat('Nc=',num2str(Nc),' Nf=',num2str(Nf),' Ns=',num2str(Ns)));
text(15.5,0.15,strcat('d=',num2str(d),' \mum'));
grid on;
