%[Eg]=bandgap(x,y)
%
%BANDGAP  Computes the band gap of several semiconductor 
%   materials based on the composition.  
%   [Eg] = bandgap(x,y) where:
%
%        x                 Concentration of In
%        y                 Concentration of As
%
%   Energy gaps returned are in units of electron volts.

function [Eg]=bandgap(x,y)

GaAs.C11 = 1.188;
GaP.C11 = 1.412;
InP.C11 = 1.022;
InAs.C11 = 0.833;

GaAs.C12 = 0.532;
GaP.C12 = 0.625;
InP.C12 = 0.576;
InAs.C12 = 0.453;

GaAs.a = -9.8;
GaP.a = -9.5;
InP.a = -8;
InAs.a = -5.8;

GaAs.b = -1.76;
GaP.b = -1.3;
InP.b = -1.55;
InAs.b = -1.8;

GaAs.a0 = 5.6533;
GaP.a0 = 5.4512;
InP.a0 = 5.8686;
InAs.a0 = 6.0584;

	      
a0 = x.*y.*InAs.a0+x.*(1-y).*InP.a0+(1-x).*y.*GaAs.a0+(1-x).*(1-y).*GaP.a0;
C11 = x.*y.*InAs.C11+x.*(1-y).*InP.C11+(1-x).*y.*GaAs.C11+(1-x).*(1-y).*GaP.C11;
C12 = x.*y.*InAs.C12+x.*(1-y).*InP.C12+(1-x).*y.*GaAs.C12+(1-x).*(1-y).*GaP.C12;
a = x.*y.*InAs.a+x.*(1-y).*InP.a+(1-x).*y.*GaAs.a+(1-x).*(1-y).*GaP.a;
b = x.*y.*InAs.b+x.*(1-y).*InP.b+(1-x).*y.*GaAs.b+(1-x).*(1-y).*GaP.b;

v = C12./(C11+C12);
plm = (1+v)./(1-v).*(a0-InP.a0)/InP.a0;
aperp = (a0-InP.a0).*(1+v)./(1-v)+InP.a0;
strainperp = (aperp-a0)./a0;

dEh = -2*a.*((C11-C12)./C11).*strainperp;
dEs = -b.*((C11+2*C12)./C11).*strainperp;

Eg = .35+1.09.*(1-x)+(1-y)+.33.*(1-x).*(1-y)-(.45+.28.*(1-y)).*x.*(1-x) ...
     -(.101+.109.*(1-x)).*y.*(1-y) ...
     +.05.*sqrt(x.*y.*(1-x).*(1-y));
  
  
if strainperp>0  
   Eg = Eg+dEh+dEs;  %Light Hole
else
	Eg	= Eg+dEh-dEs;  %Heavy Hole
end

 

